@@ -1,31 +1,31 @@
 #!/usr/bin/python
 """Functions and classes to set up Modelica_ simulations and load, analyze, and
-plot the results.
+plot the results
 
 This module provides convenient access to the most important functions and
 classes from its submodules.  These are:
 
-- To manage simulation experiments (:mod:`~modelicares.exps` module):
+- To manage simulation experiments (:mod:`~modelicares.exps` submodule):
   :mod:`~modelicares.exps.doe`, :class:`~exps.Experiment`,
-  :meth:`~exps.gen_experiments`, :class:`~exps.ParamDict`,
-  :meth:`~exps.run_models`, :meth:`~exps.write_params`, and
-  :meth:`~exps.write_script`
+  :meth:`~exps.gen_experiments`, :meth:`~exps.modelica_str`,
+  :class:`~exps.ParamDict`, :meth:`~exps.run_models`,
+  :meth:`~exps.write_params`, and :meth:`~exps.write_script`
 
-- For simulation results (:mod:`~modelicares.simres` module):
+- For simulation results (:mod:`~modelicares.simres` submodule):
   :class:`~simres.SimRes` and :class:`~simres.SimResList`
 
-- For linearization results (:mod:`~modelicares.linres` module):
+- For linearization results (:mod:`~modelicares.linres` submodule):
   :class:`~linres.LinRes` and :class:`~linres.LinResList`
 
-- To label numbers and quantities (:mod:`~modelicares.texunit` module):
+- To label numbers and quantities (:mod:`~modelicares.texunit` submodule):
   :meth:`~texunit.number_label`, :meth:`~texunit.quantity_str`, and
   :meth:`~texunit.unit2tex`
 
-- Supporting classes and functions (:mod:`~modelicares.util` module):
+- Supporting classes and functions (:mod:`~modelicares.util` submodule):
   :meth:`~util.add_arrows`, :meth:`~util.add_hlines`, :meth:`~util.add_vlines`,
   :class:`~util.ArrowLine`, :meth:`~util.closeall`, :meth:`~util.figure`,
-  :meth:`~util.load_csv`, :meth:`~util.save`, :meth:`~util.saveall`, and
-  :meth:`~util.setup_subplots`
+  :meth:`~util.load_csv`, :meth:`~util.multiglob`, :meth:`~util.save`,
+  :meth:`~util.saveall`, and :meth:`~util.setup_subplots`
 
 A function is also provided:
 
@@ -34,9 +34,10 @@ A function is also provided:
 """
 __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
-__copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
+__copyright__ = ("Copyright 2012-2014, Kevin Davies, Hawaii Natural Energy "
+                 "Institute, and Georgia Tech Research Corporation")
 __license__ = "BSD-compatible (see LICENSE.txt)"
-__version__ = "0.11.1"
+__version__ = '0.12.0'
 
 
 # Essential functions and classes
@@ -46,11 +47,12 @@ __version__ = "0.11.1"
 from modelicares.simres import SimRes, SimResList
 from modelicares.linres import LinRes, LinResList
 from modelicares.util import (add_arrows, add_hlines, add_vlines, ArrowLine,
-                              closeall, figure, load_csv, save, saveall,
-                              setup_subplots)
-from modelicares.exps import (doe, Experiment, gen_experiments, ParamDict,
-                              read_params, write_params, write_script)
-# TODO: Add run_models and include in the doc list once supported.
+                              closeall, multiglob, figure, load_csv, save,
+                              saveall, setup_subplots)
+from modelicares.exps import (doe, Experiment, gen_experiments, modelica_str,
+                              ParamDict, read_params, write_params,
+                              write_script)
+# TODO: Add run_models and include in the doc list once implemented.
 from modelicares.texunit import number_label, quantity_str, unit2tex
 
 
@@ -77,31 +79,21 @@ def load(*args):
 
     .. code-block:: python
 
-       >>> from modelicares import load
-
-       # Get the mean values of the first capacitor's voltage from two runs
-       # of the Chua circuit.
+       # Get the mean values of the first capacitor's voltage from two runs of
+       # the Chua circuit.
        >>> sims, __ = load('examples/ChuaCircuit/*/')
-       >>> sims['C1.v'].mean()
-       [0.76859528, 0.76859528]
+       >>> sims.sort()
 
-       # The values are different because the inductance was set differently:
+       >>> sims['C1.v'].mean()
+       [-1.6083468, 0.84736514]
+
+       # The voltage is different because the inductance is different:
        >>> sims['L.L'].value()
-       [10, 18]
+       [15.0, 21.0]
     """
 
-    import os
-    from glob import glob
-
-    # Get a unique list of matching filenames.
-    fnames = set()
-    for arg in args:
-        if os.path.isdir(arg):
-            fnames = fnames.union(set(glob(os.path.join(arg, '*.mat'))))
-        elif '*' in arg or '?' in arg or '[' in arg:
-            fnames = fnames.union(set(glob(arg)))
-        else:
-            fnames.add(arg)
+    # Get the set of matching filenames.
+    fnames = multiglob(args)
 
     # Load the files and append each result onto the appropriate list.
     sims = SimResList()
@@ -121,6 +113,27 @@ def load(*args):
 
 
 if __name__ == '__main__':
-    """Test the contents of this file."""
+    # Test the contents of this file.
+
+    import os
     import doctest
-    doctest.testmod()
+
+    if os.path.isdir('examples'):
+        doctest.testmod(raise_on_error=True)
+    else:
+        # Create a link to the examples folder.
+        EXAMPLE_DIR = '../examples'
+        if not os.path.isdir(EXAMPLE_DIR):
+            raise IOError("Could not find the examples folder.")
+        try:
+            os.symlink(EXAMPLE_DIR, 'examples')
+        except AttributeError:
+            raise AttributeError("This method of testing isn't supported in "
+                                 "Windows.  Use runtests.py in the base "
+                                 "folder.")
+
+        # Test the docstrings in this file.
+        doctest.testmod()
+
+        # Remove the link.
+        os.remove('examples')
