@@ -36,8 +36,9 @@ tool but something else is wrong.
 .. _Modelica: http://www.modelica.org/
 """
 
+
 if __name__ == '__main__':
-    """Test the contents of this file.
-    """
+    # Test the contents of this file.
+
     import doctest
     doctest.testmod()
