@@ -2,12 +2,12 @@
 # -*- coding: utf-8 -*-
 """Set up and help run Modelica_ simulation experiments.
 
-This module supports two approaches for managing simulations.  The first is to
+This module supports two approaches to managing simulations.  The first is to
 create a Modelica_ script (using :meth:`write_script`) and run it within
-a Modelica_ environment (see the scripts in "examples/ChuaCircuit/"), which
+a Modelica_ environment (see the scripts in *examples/ChuaCircuit/*), which
 translates and simulates the models with the prescribed settings.  The second
 approach is to execute pre-translated models.  The :meth:`run_models` method
-handles this by writing to initialization file(s) (e.g, "dsin.txt") and
+handles this by writing to initialization file(s) (e.g, *dsin.txt*) and
 launching the appropriate model executables.  The advantage of the first
 approach is that formal parameters (those that are hard-coded during
 translation) can be adjusted.  However, the second approach is faster because it
@@ -21,35 +21,32 @@ parameter may have multiple possible values.  The dictionary is passed to the
 dictionary format), which combines the values of all the variables (by
 piecewise alignment or permutation) and returns a generator to step through the
 experiments.  Finally, the generator is passed to the :meth:`write_script` or
-:meth:`run_models` function (see first paragraph).
-
+:meth:`run_models` function (see the first paragraph).
 
 **Classes:**
 
 - :class:`ParamDict` - Dictionary that prints its items as nested tuple-based
   modifiers, formatted for Modelica_
 
-- :class:`Experiment` - Named tuple class to represent a simulation experiment
-
+- :class:`Experiment` - namedtuple_ to represent a simulation experiment
 
 **Functions:**
 
 - :meth:`gen_experiments` - Return a generator for a set of simulation
-  experiments using permutation or simple element-wise grouping
+  experiments using permutation or simple element-wise grouping.
 
-- :meth:`modelica_str` - Express a Python variable as a Modelica string
+- :meth:`modelica_str` - Express a Python_ variable as a Modelica_ string.
 
 - :meth:`read_params` - Read parameter values from an initialization or final
-  values file
+  values file.
 
 - :meth:`run_models` - Run Modelica_ models via pairs of executables and
-  initialization files (not yet implemented)
+  initialization files (not yet implemented).
 
 - :meth:`write_params` - Write parameter values to a simulation initialization
-  file
-
-- :meth:`write_script` - Write a Modelica_ script to run simulations
+  file.
 
+- :meth:`write_script` - Write a Modelica_ script to run simulations.
 
 **Submodules:**
 
@@ -57,11 +54,14 @@ experiments.  Finally, the generator is passed to the :meth:`write_script` or
 
 
 .. _Modelica: http://www.modelica.org/
+.. _Python: http://www.python.org/
 .. _NumPy: http://numpy.scipy.org/
+.. _namedtuple: https://docs.python.org/2/library/collections.html#collections.namedtuple
 """
 __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
-__copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
+__copyright__ = ("Copyright 2012-2014, Kevin Davies, Hawaii Natural Energy "
+                 "Institute, and Georgia Tech Research Corporation")
 __license__ = "BSD-compatible (see LICENSE.txt)"
 
 
@@ -77,26 +77,24 @@ from types import GeneratorType
 
 import modelicares.util as util
 
-from . import doe
+from modelicares.exps import doe
 
+#pylint: disable=C0103, R0913, R0914, W0102, W0120, W0142, W0631
 
-Experiment = namedtuple('Experiment', ['model', 'params', 'args'])
-"""Named tuple class to represent a simulation experiment
+class Experiment(namedtuple('Experiment', ['model', 'params', 'args'])):
+    """namedtuple_ to represent a simulation experiment
 
-Instances of this class may be used in the *experiments* argument of
-:meth:`write_script` and :meth:`run_models`, although there are some
-differences in the entries (see those functions for details).
+    Instances of this class may be used in the *experiments* argument of
+    :meth:`write_script` and :meth:`run_models`, although there are some
+    differences in the entries (see those functions for details).
 
-**Example:**
+    **Example:**
 
-.. code-block:: python
-
-   >>> from modelicares import *
-
-   >>> experiment = Experiment('ChuaCircuit', params={'L.L': 18}, args={})
-   >>> experiment.model
-   'ChuaCircuit'
-"""
+    >>> experiment = Experiment('ChuaCircuit', params={'L.L': 18}, args={})
+    >>> experiment.model
+    'ChuaCircuit'
+    """
+    pass
 
 def gen_experiments(models=None, params={}, args={}, design=doe.fullfact):
     """Return a generator for a set of simulation experiments using permutation
@@ -130,107 +128,93 @@ def gen_experiments(models=None, params={}, args={}, design=doe.fullfact):
 
          This is a function that returns a iterable object that contains or
          generates the simulation settings.  Several options are available in
-         :mod:`modelicares.doe`.
+         :mod:`~modelicares.exps.doe`.
 
     **Example 1 (element-wise list of experiments):**
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> experiments = gen_experiments(
-       ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit']*3,
-       ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
-       ...                  design=doe.aslisted)
-       >>> for experiment in experiments:
-       ...     print(experiment.model + str(experiment.params))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=18))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=20))
-       >>> # Note that the model name must be repeated in the models argument.
+    >>> experiments = gen_experiments(
+    ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit']*3,
+    ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
+    ...                  design=doe.aslisted)
+    >>> for experiment in experiments: # doctest: +SKIP
+    ...     print(experiment.model + str(experiment.params))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=18))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=20))
+    >>> # Note that the model name must be repeated in the models argument.
 
     **Example 2 (one-factor-at-a-time; first entries are baseline):**
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> experiments = gen_experiments(
-       ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit'],
-       ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
-       ...                  design=doe.ofat)
-       >>> for experiment in experiments:
-       ...     print(experiment.model + str(experiment.params))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=18))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=20))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=16))
+    >>> experiments = gen_experiments(
+    ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit'],
+    ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
+    ...                  design=doe.ofat)
+    >>> for experiment in experiments: # doctest: +SKIP
+    ...     print(experiment.model + str(experiment.params))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=18))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=20))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=16))
 
     **Example 3 (permutation---full-factorial design of experiments):**
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> experiments = gen_experiments(
-       ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit'],
-       ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
-       ...                  design=doe.fullfact)
-       >>> for experiment in experiments:
-       ...     print(experiment.model + str(experiment.params))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=16))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=18))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=18))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=18))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=20))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=20))
-       Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=20))
+    >>> experiments = gen_experiments(
+    ...                  ['Modelica.Electrical.Analog.Examples.ChuaCircuit'],
+    ...                  {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
+    ...                  design=doe.fullfact)
+    >>> for experiment in experiments: # doctest: +SKIP
+    ...     print(experiment.model + str(experiment.params))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=16))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=18))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=18))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=18))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=20))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=20))
+    Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=20))
 
     **Example 4 (parameters given in nested form):**
 
-    .. code-block:: python
+    >>> models = ['Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis']
+    >>> params = dict(axis=dict(motor=dict(i_max=[5, 15],
+    ...                                    Ra=dict(R=[200, 300]))))
+    >>> for experiment in gen_experiments(models, params):
+    ...     print(experiment.model + str(experiment.params)) # doctest: +SKIP
+    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=200))))
+    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=15, Ra(R=200))))
+    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=300))))
+    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=15, Ra(R=300))))
 
-       >>> from modelicares import *
+    Note that the underlying representation of the parameters is actually flat:
 
-       >>> models = ['Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis']
-       >>> params = dict(axis=dict(motor=dict(i_max=[5, 15],
-       ...                                    Ra=dict(R=[200, 300]))))
-       >>> for experiment in gen_experiments(models, params):
-       ...     print(experiment.model + str(experiment.params))
-       Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=200))))
-       Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=15, Ra(R=200))))
-       Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=300))))
-       Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=15, Ra(R=300))))
+    >>> for experiment in gen_experiments(models, params): # doctest: +SKIP
+    ...     experiment.params
+    {'axis.motor.Ra.R': 200, 'axis.motor.i_max': 5}
+    {'axis.motor.Ra.R': 200, 'axis.motor.i_max': 15}
+    {'axis.motor.Ra.R': 300, 'axis.motor.i_max': 5}
+    {'axis.motor.Ra.R': 300, 'axis.motor.i_max': 15}
 
-       >>> # Note that the underlying representation of the parameters is
-       >>> # actually flat:
-       >>> for experiment in gen_experiments(models, params):
-       ...     experiment.params
-       {'axis.motor.Ra.R': 200, 'axis.motor.i_max': 5}
-       {'axis.motor.Ra.R': 200, 'axis.motor.i_max': 15}
-       {'axis.motor.Ra.R': 300, 'axis.motor.i_max': 5}
-       {'axis.motor.Ra.R': 300, 'axis.motor.i_max': 15}
-       >>> # Also note that Python dictionaries do not preserve order (and it
-       >>> # is not necessary here).
+    Also note that Python dictionaries do not preserve order (and it is not
+    necessary here).
     """
     params = util.flatten_dict(params)
     i_args = len(params) + 1
-    experiment = lambda x: Experiment(
-                             model=x[0],
-                             params=ParamDict(zip(params.keys(), x[1:i_args])),
-                             args=dict(zip(args.keys(), x[i_args:])))
+    experiment = lambda x: Experiment(model=x[0],
+                                      params=ParamDict(zip(params.keys(),
+                                                           x[1:i_args])),
+                                      args=dict(zip(args.keys(), x[i_args:])))
     try:
         return (experiment(x) for x in
-                    design(*([models] + params.values() + args.values())))
+                design(*([models] + list(params.values())
+                         + list(args.values()))))
     except TypeError:
         print("Error in call to gen_experiments(): models and all of the "
               "entries in params and args must be lists.")
 
-def modelica_str(x):
-    """Express a Python variable as a Modelica string
+def modelica_str(value):
+    """Express a Python_ value as a Modelica_ string
 
     A Boolean variable (:class:`bool`) becomes 'true' or 'false' (lowercase).
 
@@ -240,41 +224,34 @@ def modelica_str(x):
 
     Booleans:
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> # Booleans:
-       >>> modelica_str(True)
-       'true'
-       >>> modelica_str(False)
-       'false'
+    >>> # Booleans:
+    >>> modelica_str(True)
+    'true'
 
     Arrays:
 
     .. code-block:: python
 
-       >>> from numpy import array
-       >>> from modelicares import *
+       >>> import numpy as np
 
-       >>> modelica_str(array([[1, 2], [3, 4]]))
+       >>> modelica_str(np.array([[1, 2], [3, 4]]))
        '{{1, 2}, {3, 4}}'
 
-       >>> modelica_str(array([[True, True], [False, False]]))
+       >>> modelica_str(np.array([[True, True], [False, False]]))
        '{{true, true}, {false, false}}'
     """
-    if isinstance(x, bool):
-        return 'true' if x else 'false'
-    elif isinstance(x, np.ndarray):
-        x = str(x)
-        for old, new in [('\[', '{'), ('\]', '}'), (r'\n', ''),
+    if isinstance(value, bool):
+        return 'true' if value else 'false'
+    elif isinstance(value, np.ndarray):
+        value = str(value)
+        for old, new in [(r'\[', '{'), (r'\]', '}'), (r'\n', ''),
                          (' ?True', 'true'), ('False', 'false'), (' +', ', ')]:
             # Python 2.7 puts an extra space before True when representing an
             # array.
-            x = re.sub(old, new, x)
-        return x
+            value = re.sub(old, new, value)
+        return value
     else:
-        return str(x)
+        return str(value)
 
 def read_params(names, fname='dsin.txt'):
     """Read parameter values from an initialization or final values file (e.g.,
@@ -292,17 +269,13 @@ def read_params(names, fname='dsin.txt'):
 
     **Example:**
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> read_params(['L.L', 'C1.C'], 'examples/dsin.txt')
-       [18.0, 10.0]
+    >>> read_params(['Td', 'Ti'], 'examples/dsin.txt')
+    [0.1, 0.5]
     """
     # Aliases for some regular subexpressions
-    u = '\d+' # Unsigned integer
+    u = r'\d+' # Unsigned integer
     i = '[+-]?' + u # Integer
-    f = i + '(?:\.' + u + ')?(?:[Ee][+-]' + u + ')?' # Floating point number
+    f = i + r'(?:\.' + u + ')?(?:[Ee][+-]' + u + ')?' # Floating point number
 
     # Possible regular expressions for a parameter specification (with '%s' for
     # the parameter name)
@@ -353,7 +326,7 @@ def read_params(names, fname='dsin.txt'):
         for pattern in patterns:
             try:
                 return float(re.search(pattern % namere, text,
-                             re.MULTILINE).group(1))
+                                       re.MULTILINE).group(1))
             except AttributeError:
                 pass # Try the next pattern.
         else:
@@ -368,9 +341,8 @@ def read_params(names, fname='dsin.txt'):
 
 
 def run_models(experiments=[(None, {}, {})],
-               filemap = {'dslog.txt': '%s_%i.log',
-                          'dsres.mat': '%s_%i.mat'}):
-    """Run Modelica_ models via pairs of executables and initialization files.
+               filemap={'dslog.txt': '%s_%i.log', 'dsres.mat': '%s_%i.mat'}):
+    r"""Run Modelica_ models via pairs of executables and initialization files.
 
     .. Warning:: This function has not yet been implemented.
 
@@ -425,8 +397,6 @@ import os
 
 from itertools import count, product
 
-from modelicares import *
-
 model = 'Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis'
 params = {'axis.motor.i_max': [5, 9, 15],
           'axis.motor.Ra.R': [200, 250, 300]}
@@ -471,16 +441,13 @@ def write_params(params, fname='dsin.txt'):
 
     **Example:**
 
-    .. code-block:: python
-
-       >>> from modelicares import *
-
-       >>> write_params({'L.L': 10, 'C1.C': 15}, 'examples/dsin.txt')
+    >>> write_params({'Td': 1, 'Ti': 5}, 'examples/dsin.txt')
 
     .. testcleanup::
-       >>> write_params({'L.L': 18, 'C1.C': 10}, 'examples/dsin.txt')
 
-    This updates the appropriate lines in "examples/dsin.txt":
+       >>> write_params({'Td': 0.1, 'Ti': 0.5}, 'examples/dsin.txt')
+
+    This updates the appropriate lines in *examples/dsin.txt*:
 
     .. code-block:: modelica
 
@@ -492,23 +459,25 @@ def write_params(params, fname='dsin.txt'):
     for key, value in params.items():
         if isinstance(value, bool):
             params[key] = 1 if value else 0
-        assert not isinstance(value, np.ndarray), ("Arrays must be split "
-            "into scalars for the simulation initialization file.")
-        assert not isinstance(value, string_types), ("Strings cannot be "
-            "used as values in the simulation initialization file.")
+        assert not isinstance(value, np.ndarray), (
+            "Arrays must be split into scalars for the simulation "
+            "initialization file.")
+        assert not isinstance(value, string_types), (
+            "Strings cannot be used as values in the simulation initialization "
+            "file.")
 
     # Aliases for some regular subexpressions
-    u = '\d+' # Unsigned integer
+    u = r'\d+' # Unsigned integer
     i = '[+-]?' + u # Integer
-    f = i + '(?:\.' + u + ')?(?:[Ee][+-]' + u + ')?' # Floating point number
+    f = i + r'(?:\.' + u + ')?(?:[Ee][+-]' + u + ')?' # Floating point number
 
     # Possible regular expressions for a parameter specification (with '%s' for
     # the parameter name)
     patterns = [# Dymola 1- or 2-line parameter specification
                 (r'(^\s*%s\s+)%s(\s+%s\s+%s\s+%s\s+%s\s*#\s*%s\s*$)'
                  % (i, f, f, f, u, u, '%s')),
-                (r'(^\s*)' + i + '(\s*#\s*%s)'),
-                (r'(^\s*)' + f + '(\s*#\s*%s)'),
+                r'(^\s*)' + i + r'(\s*#\s*%s)',
+                r'(^\s*)' + f + r'(\s*#\s*%s)',
                 # See read_params() for a description of the columns.
                ]
     # These are tried in order until there is a match.  The first group or pair
@@ -524,9 +493,9 @@ def write_params(params, fname='dsin.txt'):
     for name, value in params.items():
         namere = re.escape(name) # Escape the dots, square brackets, etc.
         for pattern in patterns:
-            text, n = re.subn(pattern % namere, r'\g<1>%s\2' % value, text, 1,
-                              re.MULTILINE)
-            if n == 1:
+            text, num = re.subn(pattern % namere, r'\g<1>%s\2' % value, text, 1,
+                                re.MULTILINE)
+            if num == 1:
                 break
         else:
             raise AssertionError(
@@ -543,7 +512,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
                  command='simulateModel',
                  results=['dsin.txt', 'dslog.txt', 'dsres.mat', 'dymosim%x',
                           'dymolalg.txt']):
-    """Write a Modelica_ script to run simulations.
+    r"""Write a Modelica_ script to run simulations.
 
     **Arguments**:
 
@@ -646,7 +615,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
 
     .. code-block:: python
 
-       >>> from modelicares import *
+       >>> from modelicares import Experiment, write_script
 
        >>> experiment = Experiment(model='Modelica.Electrical.Analog.Examples.ChuaCircuit',
        ...                         params={},
@@ -655,10 +624,11 @@ def write_script(experiments=[(None, {}, {})], packages=[],
        ...              fname="examples/ChuaCircuit/run-sims1.mos") # doctest: +ELLIPSIS
        (['ChuaCircuit'], '...examples/ChuaCircuit')
 
-    In "examples/ChuaCircuit/run-sims1.mos":
+    In *examples/ChuaCircuit/run-sims1.mos*:
 
     .. code-block:: modelica
 
+       // Modelica experiment script written by modelicares ...
        import Modelica.Utilities.Files.copy;
        import Modelica.Utilities.Files.createDirectory;
        Advanced.TranslationInCommandLog = true "Also include translation log in command log";
@@ -666,7 +636,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
        destination = ".../examples/ChuaCircuit/";
 
        // Experiment 1
-       ok = simulateModel("Modelica.Electrical.Analog.Examples.ChuaCircuit", stopTime=2500);
+       ok = simulateModel(problem="Modelica.Electrical.Analog.Examples.ChuaCircuit", stopTime=2500);
        if ok then
            savelog();
            createDirectory(destination + "1");
@@ -676,6 +646,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
            copy("dymosim", destination + "1/dymosim", true);
            copy("dymolalg.txt", destination + "1/dymolalg.txt", true);
        end if;
+       clearlog();
 
        exit();
 
@@ -685,7 +656,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
 
     .. code-block:: python
 
-       >>> from modelicares import *
+       >>> from modelicares import gen_experiments, write_script
 
        >>> experiments = gen_experiments(
        ...     models=["Modelica.Electrical.Analog.Examples.ChuaCircuit"],
@@ -693,12 +664,10 @@ def write_script(experiments=[(None, {}, {})], packages=[],
        ...             'C1.C': [8, 10],
        ...             'C2.C': [80, 100, 120]})
        >>> write_script(experiments, fname="examples/ChuaCircuit/run-sims2.mos") # doctest: +ELLIPSIS
-       (['ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit'], '...examples/ChuaCircuit')
+       (['ChuaCircuit', ..., 'ChuaCircuit'], '...examples/ChuaCircuit')
 
-    In "examples/ChuaCircuit/run-sims2.mos", there are commands to run and
-    save results from 12 simulation experiments.
-
-    .. _Python: http://www.python.org
+    In *examples/ChuaCircuit/run-sims2.mos*, there are commands to run and save
+    results from twelve simulations.
     """
     # Preprocess the arguments.
     if not isinstance(experiments, (list, GeneratorType)):
@@ -717,7 +686,8 @@ def write_script(experiments=[(None, {}, {})], packages=[],
                   % date.isoformat(date.today()))
         mos.write('import Modelica.Utilities.Files.copy;\n')
         mos.write('import Modelica.Utilities.Files.createDirectory;\n')
-        mos.write('Advanced.TranslationInCommandLog = true "Also include translation log in command log";\n')
+        mos.write('Advanced.TranslationInCommandLog = true "Also include '
+                  'translation log in command log";\n')
         mos.write('cd("%s");\n' % working_dir)
         for package in packages:
             if package.endswith('.mos'):
@@ -727,7 +697,8 @@ def write_script(experiments=[(None, {}, {})], packages=[],
                 if package.endswith('.mo'):
                     mos.write('openModel("%s");\n' % package)
                 else:
-                    mos.write('openModel("%s");\n' % os.path.join(package, 'package.mo'))
+                    mos.write('openModel("%s");\n' % os.path.join(package,
+                                                                  'package.mo'))
                 mos.write('cd("%s");\n' % working_dir)
         mos.write('destination = "%s";\n'
                   % (os.path.normpath(results_dir) + os.path.sep))
@@ -743,11 +714,11 @@ def write_script(experiments=[(None, {}, {})], packages=[],
             # Create an abbreviated name for the model.
             models.append(model[model.rfind('.')+1:])
 
-            # Write to the Modelica script.
+            # Write to the Dymola script.
             mos.write('// Experiment %i\n' % i)
             if model:
                 params = ParamDict(util.flatten_dict(params))
-                args['problem'] =  '"%s%s"' % (model, params)
+                args['problem'] = '"%s%s"' % (model, params)
             if args:
                 mos.write('ok = %s%s;\n' % (command, ParamDict(args)))
             else:
@@ -776,50 +747,51 @@ class ParamDict(dict):
     Otherwise, this class is the same as :class:`dict`.  The underlying
     structure is not nested or reformatted---only the informal representation
     (:meth:`ParamDict.__str__`).
+
+    In printing this dictionary (string representation), each key is interpreted
+    as a parameter name (including the full model path in Modelica_ dot
+    notation) and each entry is a parameter value.  The value may be a number
+    (integer or float), Boolean constant (in Python_ format---*True* or *False*,
+    not 'true' or 'false'), string, or NumPy_ arrays of these.  Modelica_
+    strings must be given with double quotes included (e.g., '"hello"').
+    Enumerations may be used as values (e.g., 'Axis.x').  Values may include
+    functions, but the entire value must be expressed as a Python_ string (e.g.,
+    'fill(true, 2, 2)').  Items with a value of *None* are not shown.
+
+    Redeclarations and other prefixes must be included in the key along with the
+    name of the instance (e.g., 'redeclare Region regions[n_x, n_y, n_z]').  The
+    single quotes must be explicitly included for instance names that contain
+    symbols (e.g., "'H+'").
+
+    Note that Python_ dictionaries do not preserve
+    order.
+
+    **Examples:**
+
+    .. code-block:: python
+
+       >>> import numpy as np
+
+       >>> d = ParamDict({'a': 1, 'b.c': np.array([2, 3]), 'b.d': False,
+       ...                'b.e': '"hello"', 'b.f': None})
+       >>> print(d) # doctest: +SKIP
+       (a=1, b(c={2, 3}, e="hello", d=false))
+
+    The formal representation (and the internal structure) is not affected:
+
+    >>> d # doctest: +SKIP
+    {'a': 1, 'b.c': array([2, 3]), 'b.f': None, 'b.e': '"hello"', 'b.d': False}
+
+    An empty dictionary prints as an empty string (not "()"):
+
+    >>> print(ParamDict({}))
+    <BLANKLINE>
     """
     def __str__(self):
         """Map the :class:`ParamDict` instance to a string using tuple-based
         modifiers formatted for Modelica_.
-
-        Each key is interpreted as a parameter name (including the full model
-        path in Modelica_ dot notation) and each entry is a parameter value.
-        The value may be a number (integer or float), Boolean constant (in
-        Python_ format---*True* or *False*, not 'true' or 'false'), string, or
-        NumPy_ arrays of these.  Modelica_ strings must be given with double
-        quotes included (e.g., '"hello"').  Enumerations may be used as values
-        (e.g., 'Axis.x').  Values may include functions, but the entire value
-        must be expressed as a Python_ string (e.g., 'fill(true, 2, 2)').
-        Items with a value of *None* are not shown.
-
-        Redeclarations and other prefixes must be included in the key along
-        with the name of the instance (e.g., 'redeclare Region
-        regions[n_x, n_y, n_z]').  The single quotes must be explicitly
-        included for instance names that contain symbols (e.g., "'H+'").
-
-        Note that Python_ dictionaries do not preserve order.
-
-        **Example:**
-
-        .. code-block:: python
-
-           >>> from numpy import array
-           >>> from modelicares import *
-
-           >>> d = ParamDict({'a': 1, 'b.c': array([2, 3]), 'b.d': False,
-           ...                'b.e': '"hello"', 'b.f': None})
-           >>> print(d)
-           (a=1, b(c={2, 3}, e="hello", d=false))
-
-           # The formal representation (and the internal structure) is unaffected:
-           >>> d
-           {'a': 1, 'b.c': array([2, 3]), 'b.f': None, 'b.e': '"hello"', 'b.d': False}
-
-           # An empty dictionary prints as an empty string (not "()"):
-           print(ParamDict({}))
-
-        .. _Python: http://www.python.org/
         """
-        def _str(d):
+        def _str(dictionary):
             """Return a string representation of a dictionary in the form of
             tuple-based modifiers (e.g., (a=1, b(c={2, 3}, d=false))).
 
@@ -827,7 +799,7 @@ class ParamDict(dict):
             arrays in Modelica_.
             """
             elements = []
-            for key, value in d.items():
+            for key, value in dictionary.items():
                 if isinstance(value, ParamDict):
                     elements.append('%s%s' % (key, value))
                 elif value is not None:
@@ -853,6 +825,28 @@ class ParamDict(dict):
 
 
 if __name__ == '__main__':
-    """Test the contents of this file."""
+    # Test the contents of this file.
+
     import doctest
-    doctest.testmod()
+
+    if os.path.isdir('examples'):
+        doctest.testmod()
+    else:
+        # Create a link to the examples folder.
+        for example_dir in ['../examples', '../../examples']:
+            if os.path.isdir(example_dir):
+                break
+        else:
+            raise IOError("Could not find the examples folder.")
+        try:
+            os.symlink(example_dir, 'examples')
+        except AttributeError:
+            raise AttributeError("This method of testing isn't supported in "
+                                 "Windows.  Use runtests.py in the base "
+                                 "folder.")
+
+        # Test the docstrings in this file.
+        doctest.testmod()
+
+        # Remove the link.
+        os.remove('examples')
